===================
Merging Seismograms
===================

The following example shows how to merge and plot three seismograms with
overlaps, the longest one is taken to be the right one. Please also refer to
the documentation of the :meth:`~obspy.core.stream.Stream.merge` method. 

.. plot:: tutorial/code_snippets/merging_seismograms.py
   :include-source:
